// src/app/dashboard/ads/page.tsx
'use client'
import { useState } from 'react'
import { 
  Megaphone,
  Instagram,
  Image as ImageIcon,
  Type,
  Video,
  Clock,
  Edit2,
  Trash2,
  TrendingUp,
  TrendingDown 
} from 'lucide-react'
import { useTheme } from '@/contexts/themecontext'

// Mock scheduled posts
const scheduledPosts = [
  {
    id: 1,
    content: "Discover our new collection...",
    type: "image",
    platform: "instagram",
    scheduledFor: "2024-12-30T10:00:00",
    status: "scheduled",
    imageUrl: "https://picsum.photos/400/400",
    analytics: {
      reach: 1200,
      engagement: 320,
      clicks: 45
    }
  },
  {
    id: 2,
    content: "Behind the scenes look...",
    type: "video",
    platform: "tiktok",
    scheduledFor: "2024-12-31T15:30:00",
    status: "draft",
    imageUrl: "https://picsum.photos/400/401",
    analytics: {
      reach: 2500,
      engagement: 850,
      clicks: 120
    }
  }
]

export default function AdsPage() {
  const [activeTab, setActiveTab] = useState('create')
  const { theme } = useTheme()

  return (
    <div className="p-6">
      {/* Header */}
      <div className="mb-8">
        <h1 className={`text-4xl font-bold ${theme === 'dark' ? 'text-white' : 'text-gray-900'} mb-2 flex items-center`}>
          <Megaphone className="w-8 h-8 mr-3 text-orange-500" />
          Content Manager
        </h1>
        <p className={`${theme === 'dark' ? 'text-gray-400' : 'text-gray-600'} text-lg`}>Create, schedule, and track your social media content</p>
      </div>

      {/* Main Navigation */}
      <div className={`flex space-x-1 ${theme === 'dark' ? 'bg-gray-800' : 'bg-white'} p-1 rounded-lg mb-8 max-w-md shadow-lg`}>
        {['create', 'scheduled', 'analytics'].map((tab) => (
          <button
            key={tab}
            onClick={() => setActiveTab(tab)}
            className={`flex-1 px-4 py-2 rounded-md text-sm font-medium transition-colors ${
              activeTab === tab 
                ? 'bg-orange-500 text-white' 
                : `${theme === 'dark' ? 'text-gray-400 hover:text-white hover:bg-gray-700' : 'text-gray-600 hover:text-gray-900 hover:bg-gray-100'}`
            }`}
          >
            {tab.charAt(0).toUpperCase() + tab.slice(1)}
          </button>
        ))}
      </div>

      {/* Create Content Section */}
      {activeTab === 'create' && (
        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
          {/* Quick Create Options */}
          <button className={`p-6 ${theme === 'dark' ? 'bg-gray-800' : 'bg-white'} rounded-lg hover:ring-2 hover:ring-orange-500/50 transition-all group shadow-lg`}>
            <ImageIcon className="w-8 h-8 mb-4 text-orange-500" />
            <h3 className={`text-lg font-semibold ${theme === 'dark' ? 'text-white' : 'text-gray-900'} mb-2`}>Image Post</h3>
            <p className={`${theme === 'dark' ? 'text-gray-400' : 'text-gray-600'} text-sm`}>Create image-based posts with AI assistance</p>
          </button>

          <button className={`p-6 ${theme === 'dark' ? 'bg-gray-800' : 'bg-white'} rounded-lg hover:ring-2 hover:ring-orange-500/50 transition-all group shadow-lg`}>
            <Video className="w-8 h-8 mb-4 text-orange-500" />
            <h3 className={`text-lg font-semibold ${theme === 'dark' ? 'text-white' : 'text-gray-900'} mb-2`}>Video Post</h3>
            <p className={`${theme === 'dark' ? 'text-gray-400' : 'text-gray-600'} text-sm`}>Create and edit video content</p>
          </button>

          <button className={`p-6 ${theme === 'dark' ? 'bg-gray-800' : 'bg-white'} rounded-lg hover:ring-2 hover:ring-orange-500/50 transition-all group shadow-lg`}>
            <Type className="w-8 h-8 mb-4 text-orange-500" />
            <h3 className={`text-lg font-semibold ${theme === 'dark' ? 'text-white' : 'text-gray-900'} mb-2`}>Text Post</h3>
            <p className={`${theme === 'dark' ? 'text-gray-400' : 'text-gray-600'} text-sm`}>Generate engaging captions and text content</p>
          </button>
        </div>
      )}

      {/* Scheduled Content Section */}
      {activeTab === 'scheduled' && (
        <div className="space-y-6">
          {/* Calendar View Toggle */}
          <div className={`${theme === 'dark' ? 'bg-gray-800' : 'bg-white'} rounded-lg p-6 mb-6 shadow-lg`}>
            <div className="flex items-center justify-between mb-4">
              <h2 className={`text-lg font-semibold ${theme === 'dark' ? 'text-white' : 'text-gray-900'}`}>Content Calendar</h2>
              <button className="px-4 py-2 bg-orange-500 text-white rounded-md hover:bg-orange-600 transition-colors">
                Schedule New Post
              </button>
            </div>
            {/* Calendar would go here */}
          </div>

          {/* Scheduled Posts List */}
          <div className="space-y-4">
            {scheduledPosts.map((post) => (
              <div key={post.id} className={`${theme === 'dark' ? 'bg-gray-800' : 'bg-white'} rounded-lg p-4 shadow-lg`}>
                <div className="flex items-start gap-4">
                  {/* Post Preview */}
                  <div className={`w-24 h-24 ${theme === 'dark' ? 'bg-gray-700' : 'bg-gray-100'} rounded-lg overflow-hidden flex-shrink-0`}>
                    <img 
                      src={post.imageUrl} 
                      alt="Post preview" 
                      className="w-full h-full object-cover"
                    />
                  </div>

                  {/* Post Details */}
                  <div className="flex-1">
                    <div className="flex items-center justify-between mb-2">
                      <div className="flex items-center gap-2">
                        <Instagram className="w-4 h-4 text-pink-500" />
                        <span className={`text-sm ${theme === 'dark' ? 'text-gray-400' : 'text-gray-600'}`}>{post.platform}</span>
                        <span className={`px-2 py-0.5 rounded-full text-xs ${
                          post.status === 'scheduled' 
                            ? 'bg-green-500/10 text-green-500' 
                            : 'bg-yellow-500/10 text-yellow-500'
                        }`}>
                          {post.status}
                        </span>
                      </div>
                      <div className="flex items-center gap-2">
                        <button className={`p-1 ${theme === 'dark' ? 'hover:bg-gray-700' : 'hover:bg-gray-100'} rounded`}>
                          <Edit2 className={`w-4 h-4 ${theme === 'dark' ? 'text-gray-400' : 'text-gray-500'}`} />
                        </button>
                        <button className={`p-1 ${theme === 'dark' ? 'hover:bg-gray-700' : 'hover:bg-gray-100'} rounded`}>
                          <Trash2 className={`w-4 h-4 ${theme === 'dark' ? 'text-gray-400' : 'text-gray-500'}`} />
                        </button>
                      </div>
                    </div>
                    <p className={`${theme === 'dark' ? 'text-white' : 'text-gray-900'} mb-2`}>{post.content}</p>
                    <div className={`flex items-center text-sm ${theme === 'dark' ? 'text-gray-400' : 'text-gray-600'}`}>
                      <Clock className="w-4 h-4 mr-1" />
                      Scheduled for {new Date(post.scheduledFor).toLocaleString()}
                    </div>
                  </div>
                </div>
              </div>
            ))}
          </div>
        </div>
      )}

      {/* Analytics Section */}
      {activeTab === 'analytics' && (
        <div>
          {/* Overview Cards */}
          <div className="grid grid-cols-1 md:grid-cols-3 gap-6 mb-8">
            {[
              { title: 'Total Reach', value: '24.5K', change: '+12.3%', trending: 'up' },
              { title: 'Engagement Rate', value: '3.8%', change: '+2.1%', trending: 'up' },
              { title: 'Click-through Rate', value: '2.4%', change: '-0.8%', trending: 'down' }
            ].map((stat, index) => (
              <div key={index} className={`${theme === 'dark' ? 'bg-gray-800' : 'bg-white'} rounded-lg p-6 shadow-lg`}>
                <h3 className={`${theme === 'dark' ? 'text-gray-400' : 'text-gray-600'} mb-2 text-sm`}>{stat.title}</h3>
                <div className={`text-2xl font-bold ${theme === 'dark' ? 'text-white' : 'text-gray-900'}`}>{stat.value}</div>
                <div className={`text-sm flex items-center mt-2 ${
                  stat.trending === 'up' ? 'text-green-500' : 'text-red-500'
                }`}>
                  {stat.trending === 'up' ? <TrendingUp className="w-4 h-4 mr-1" /> : <TrendingDown className="w-4 h-4 mr-1" />}
                  {stat.change}
                </div>
              </div>
            ))}
          </div>

          {/* Performance Chart */}
          <div className={`${theme === 'dark' ? 'bg-gray-800' : 'bg-white'} rounded-lg p-6 shadow-lg`}>
            <h2 className={`text-lg font-semibold ${theme === 'dark' ? 'text-white' : 'text-gray-900'} mb-4`}>Performance Over Time</h2>
            <div className="h-64">
              {/* Chart would go here */}
            </div>
          </div>
        </div>
      )}
    </div>
  )
}