// Inside your dashboard layout, add state for dropdown
import { useState } from 'react'
import { ChevronDown, PlusCircle } from 'lucide-react'

// Mock data for workspaces
const workspaces = [
  { id: 1, name: "My Workspace", initial: "M", color: "bg-blue-500" },
  { id: 2, name: "Design Team", initial: "D", color: "bg-purple-500" },
  { id: 3, name: "Marketing", initial: "M", color: "bg-emerald-500" },
]

// Component for workspace selection
export function WorkspaceSelector() {
  const [isOpen, setIsOpen] = useState(false)
  const [selectedWorkspace, setSelectedWorkspace] = useState(workspaces[0])

  return (
    <div className="relative">
      {/* Trigger Button */}
      <button
        onClick={() => setIsOpen(!isOpen)}
        className="w-full p-4 flex items-center space-x-2 hover:bg-gray-100 dark:hover:bg-gray-800 rounded-lg transition-colors"
      >
        <div className={`${selectedWorkspace.color} w-8 h-8 rounded flex items-center justify-center text-white font-bold`}>
          {selectedWorkspace.initial}
        </div>
        <div className="flex-1">
          <h1 className="text-gray-900 dark:text-white font-medium text-left">
            {selectedWorkspace.name}
          </h1>
        </div>
        <ChevronDown className={`w-4 h-4 text-gray-500 transition-transform duration-200 ${isOpen ? 'transform rotate-180' : ''}`} />
      </button>

      {/* Dropdown Menu */}
      {isOpen && (
        <>
          {/* Backdrop for closing dropdown */}
          <div 
            className="fixed inset-0 z-10"
            onClick={() => setIsOpen(false)}
          />

          <div className="absolute top-full left-0 w-full mt-2 py-2 bg-white dark:bg-gray-800 rounded-lg shadow-lg border border-gray-200 dark:border-gray-700 z-20">
            <div className="px-3 py-2 text-xs font-semibold text-gray-500 dark:text-gray-400 uppercase tracking-wider">
              Your Workspaces
            </div>
            
            <div className="mt-2">
              {workspaces.map((workspace) => (
                <button
                  key={workspace.id}
                  onClick={() => {
                    setSelectedWorkspace(workspace)
                    setIsOpen(false)
                  }}
                  className={`w-full px-3 py-2 flex items-center space-x-2 hover:bg-gray-100 dark:hover:bg-gray-700 transition-colors
                    ${selectedWorkspace.id === workspace.id ? 'bg-gray-50 dark:bg-gray-700' : ''}`}
                >
                  <div className={`${workspace.color} w-6 h-6 rounded flex items-center justify-center text-white font-medium text-sm`}>
                    {workspace.initial}
                  </div>
                  <span className="text-gray-900 dark:text-white text-sm">
                    {workspace.name}
                  </span>
                </button>
              ))}
            </div>

            <div className="h-px bg-gray-200 dark:bg-gray-700 my-2" />
            
            <button
              onClick={() => {
                // Handle new workspace creation
                console.log('Create new workspace')
                setIsOpen(false)
              }}
              className="w-full px-3 py-2 flex items-center space-x-2 text-gray-700 dark:text-gray-300 hover:bg-gray-100 dark:hover:bg-gray-700 transition-colors"
            >
              <PlusCircle className="w-4 h-4" />
              <span className="text-sm">Create New Workspace</span>
            </button>
          </div>
        </>
      )}
    </div>
  )
}