// src/app/dashboard/suggestions/page.tsx
'use client'
import { 
  Lightbulb,
  TrendingUp,
  DollarSign,
  Target,
  ArrowRight,
  ShoppingBag,
  ArrowUpRight
} from 'lucide-react'
import Link from 'next/link'
import { useTheme } from '@/contexts/themecontext'

const suggestions = [
  {
    id: 1,
    type: 'Tool',
    title: 'Video Editing Suite',
    description: 'Professional video editing tool optimized for social media',
    trendLink: 'Rising demand in vertical video content',
    roi: 'Expected ROI: 3.2x',
    price: '$49/month',
    category: 'Content Creation',
    designGuide: true
  },
  {
    id: 2,
    type: 'Service',
    title: 'Social Media Strategy',
    description: 'Personalized content calendar & hashtag research',
    trendLink: 'Engagement optimization trending up',
    roi: 'Expected ROI: 2.8x',
    price: '$299/month',
    category: 'Marketing',
    designGuide: true
  },
  {
    id: 3,
    type: 'Tool',
    title: 'AI Caption Generator',
    description: 'Create engaging captions using AI technology',
    trendLink: 'AI tools adoption growing',
    roi: 'Expected ROI: 4.1x',
    price: '$29/month',
    category: 'AI Tools',
    designGuide: false
  }
]

export default function SuggestionsPage() {
  const { theme } = useTheme()

  return (
    <div className="p-6">
      {/* Header */}
      <div className="mb-8">
        <h1 className={`text-4xl font-bold ${theme === 'dark' ? 'text-white' : 'text-gray-900'} mb-2 flex items-center`}>
          <Lightbulb className="w-8 h-8 mr-3 text-yellow-500" />
          Suggestions
        </h1>
        <p className={`${theme === 'dark' ? 'text-gray-400' : 'text-gray-600'} text-lg`}>Discover tools and services to grow your presence</p>
      </div>

      {/* Suggestions Grid */}
      <div className="grid grid-cols-1 lg:grid-cols-3 gap-6">
        {suggestions.map((item) => (
          <div key={item.id} className={`${theme === 'dark' ? 'bg-gray-800' : 'bg-white'} rounded-lg p-6 hover:ring-2 hover:ring-blue-500/50 transition-all shadow-lg`}>
            {/* Header */}
            <div className="flex items-start justify-between mb-4">
              <span className="px-2 py-1 bg-blue-500/10 text-blue-400 rounded text-sm">
                {item.type}
              </span>
              <span className={`text-xl font-bold ${theme === 'dark' ? 'text-white' : 'text-gray-900'}`}>{item.price}</span>
            </div>

            {/* Content */}
            <h3 className={`text-xl font-bold ${theme === 'dark' ? 'text-white' : 'text-gray-900'} mb-2`}>{item.title}</h3>
            <p className={`${theme === 'dark' ? 'text-gray-400' : 'text-gray-600'} mb-4`}>{item.description}</p>

            {/* Links */}
            <div className="space-y-3 mb-6">
              <Link 
                href="/dashboard/trends" 
                className="flex items-center text-sm text-blue-400 hover:text-blue-300"
              >
                <TrendingUp className="w-4 h-4 mr-2" />
                <span>{item.trendLink}</span>
                <ArrowUpRight className="w-4 h-4 ml-2" />
              </Link>

              {item.designGuide && (
                <Link 
                  href="/dashboard/design" 
                  className="flex items-center text-sm text-purple-400 hover:text-purple-300"
                >
                  <Target className="w-4 h-4 mr-2" />
                  <span>View design guide</span>
                  <ArrowUpRight className="w-4 h-4 ml-2" />
                </Link>
              )}

              <div className="flex items-center text-sm">
                <DollarSign className="w-4 h-4 mr-2 text-yellow-500" />
                <span className={`${theme === 'dark' ? 'text-gray-300' : 'text-gray-600'}`}>{item.roi}</span>
              </div>
            </div>

            {/* Action Button */}
            <button className="w-full bg-blue-500 hover:bg-blue-600 text-white rounded-lg px-4 py-2 flex items-center justify-center space-x-2 transition-colors">
              <ShoppingBag className="w-4 h-4" />
              <span>Learn More</span>
            </button>
          </div>
        ))}
      </div>

      {/* Quick Actions */}
      <div className="grid grid-cols-1 md:grid-cols-3 gap-4 mt-8">
        {['Compare Solutions', 'Schedule Demo', 'Custom Solution'].map((action) => (
          <button 
            key={action}
            className={`${theme === 'dark' ? 'bg-gray-800 hover:bg-gray-700' : 'bg-white hover:bg-gray-50'} rounded-lg p-4 flex items-center justify-between transition-colors shadow-lg`}
          >
            <span className={theme === 'dark' ? 'text-white' : 'text-gray-900'}>{action}</span>
            <ArrowRight className={`w-5 h-5 ${theme === 'dark' ? 'text-gray-400' : 'text-gray-500'}`} />
          </button>
        ))}
      </div>
    </div>
  )
}