// src/app/dashboard/trends/page.tsx
'use client'
import { 
  Instagram, 
  TrendingUp, 
  Users, 
  Activity,
} from 'lucide-react'
import { LineChart, Line, XAxis, YAxis, CartesianGrid, Tooltip, ResponsiveContainer, AreaChart, Area } from 'recharts'
import { useTheme } from '@/contexts/themecontext'

// Mock data remains the same
const audienceGrowthData = [
  { date: 'Jan', instagram: 15000, tiktok: 25000 },
  { date: 'Feb', instagram: 17000, tiktok: 32000 },
  { date: 'Mar', instagram: 19000, tiktok: 38000 },
  { date: 'Apr', instagram: 22000, tiktok: 45000 },
  { date: 'May', instagram: 24000, tiktok: 52000 },
  { date: 'Jun', instagram: 28000, tiktok: 58000 },
]

const engagementData = [
  { time: '12am', instagram: 1.2, tiktok: 2.5 },
  { time: '4am', instagram: 0.8, tiktok: 1.8 },
  { time: '8am', instagram: 2.8, tiktok: 3.9 },
  { time: '12pm', instagram: 3.9, tiktok: 4.8 },
  { time: '4pm', instagram: 3.5, tiktok: 5.2 },
  { time: '8pm', instagram: 2.9, tiktok: 4.1 },
]

const trendingHashtags = [
  { tag: '#design', posts: '2.1M', growth: '+12%' },
  { tag: '#ui', posts: '1.8M', growth: '+8%' },
  { tag: '#webdesign', posts: '1.6M', growth: '+15%' },
  { tag: '#minimal', posts: '1.2M', growth: '+5%' },
]

export default function TrendsPage() {  
  const { theme } = useTheme()
const isDark = theme === 'dark'

// Define theme-dependent colors
const colors = {
  gridStroke: isDark ? '#374151' : '#E5E7EB',
  axisStroke: isDark ? '#9CA3AF' : '#6B7280',
  tooltipBg: isDark ? '#1F2937' : '#ffffff',
  tooltipBorder: isDark ? 'none' : '1px solid #E5E7EB',
  tooltipText: isDark ? '#ffffff' : '#111827',
}
  return (
    <div className="p-6">
      {/* Header */}
      <div className="mb-8">
        <h1 className="text-4xl font-bold dark:text-white  mb-2 flex items-center">Tendances des réseaux sociaux</h1>
        <p className="text-gray-400 text-lg dark:text-gray-400">Suivez les performances de vos réseaux sociaux et les insights de votre audience</p>
      </div>

      {/* Platform Stats */}
      <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-6 mb-8">
        {/* Instagram Stats */}
        <div className="bg-white dark:bg-gradient-to-r from-purple-500/10 to-pink-500/10 rounded-lg p-6 border border-gray-200 dark:border-transparent shadow-sm">
          <div className="flex items-center justify-between mb-4">
            <Instagram className="w-6 h-6 text-pink-500" />
            <span className="text-green-500 flex items-center text-sm">
              <TrendingUp className="w-4 h-4 mr-1" /> 12%
            </span>
          </div>
          <h3 className="text-2xl font-bold text-gray-900  mb-1">24.8k</h3>
          <p className="text-gray-600 dark:text-gray-400 text-sm">Abonnés Instagram</p>
        </div>

        {/* TikTok Stats */}
        <div className="bg-white dark:bg-gradient-to-r from-blue-500/10 to-cyan-500/10 rounded-lg p-6 border border-gray-200 dark:border-transparent shadow-sm">
          <div className="flex items-center justify-between mb-4">
            <svg className="w-6 h-6 text-cyan-500" viewBox="0 0 24 24" fill="currentColor">
              <path d="M19.59 6.69a4.83 4.83 0 01-3.77-4.25V2h-3.45v13.67a2.89 2.89 0 01-5.2 1.74 2.89 2.89 0 012.31-4.64 2.93 2.93 0 01.88.13V9.4a6.84 6.84 0 00-1-.05A6.33 6.33 0 005 20.1a6.34 6.34 0 0011-4.31v-7a8.16 8.16 0 004.65 1.48V6.69z"/>
            </svg>
            <span className="text-green-500 flex items-center text-sm">
              <TrendingUp className="w-4 h-4 mr-1" /> 28%
            </span>
          </div>
          <h3 className="text-2xl font-bold text-gray-900  mb-1">58.2k</h3>
          <p className="text-gray-600 dark:text-gray-400 text-sm">Abonnés TikTok</p>
        </div>

        {/* Engagement Rate */}
        <div className="bg-white dark:bg-gradient-to-r from-green-500/10 to-emerald-500/10 rounded-lg p-6 border border-gray-200 dark:border-transparent shadow-sm">
          <div className="flex items-center justify-between mb-4">
            <Activity className="w-6 h-6 text-emerald-500" />
            <span className="text-green-500 flex items-center text-sm">
              <TrendingUp className="w-4 h-4 mr-1" /> 5%
            </span>
          </div>
          <h3 className="text-2xl font-bold text-gray-900  mb-1">4.2%</h3>
          <p className="text-gray-600 dark:text-gray-400 text-sm">Taux d&apos;engagement moyen</p>
        </div>

        {/* Audience Reach */}
        <div className="bg-white dark:bg-gradient-to-r from-orange-500/10 to-amber-500/10 rounded-lg p-6 border border-gray-200 dark:border-transparent shadow-sm">
          <div className="flex items-center justify-between mb-4">
            <Users className="w-6 h-6 text-amber-500" />
            <span className="text-green-500 flex items-center text-sm">
              <TrendingUp className="w-4 h-4 mr-1" /> 15%
            </span>
          </div>
          <h3 className="text-2xl font-bold text-gray-900  mb-1">1.2M</h3>
          <p className="text-gray-600 dark:text-gray-400 text-sm">Portée totale</p>
        </div>
      </div>

      {/* Charts Section */}
      <div className="grid grid-cols-1 lg:grid-cols-2 gap-6 mb-8">
        {/* Audience Growth Chart */}
        <div className="bg-white dark:bg-gray-800 rounded-lg p-6 border border-gray-200 dark:border-transparent shadow-sm">
          <div className="flex items-center justify-between mb-6">
            <h2 className="text-xl font-bold text-gray-900 dark:text-white">Croissance de l&apos;audience</h2>
            <select className="bg-gray-100 dark:bg-gray-700 text-gray-900 dark:text-white text-sm rounded-md px-3 py-2 border-0 focus:ring-2 focus:ring-blue-500">
              <option>6 derniers mois</option>
              <option>L&apos;année dernière</option>
            </select>
          </div>
          <div className="h-64">
            <ResponsiveContainer width="100%" height="100%">
              <AreaChart data={audienceGrowthData}>
                <CartesianGrid strokeDasharray="3 3" stroke={colors.gridStroke} />
                <XAxis dataKey="date" stroke={colors.axisStroke} />
                <YAxis stroke={colors.axisStroke} />
                <Tooltip 
                  contentStyle={{ 
                    backgroundColor: colors.tooltipBg,
                    border: colors.tooltipBorder,
                    borderRadius: '0.5rem',
                    color: colors.tooltipText
                  }}
                />
                <Area 
                  type="monotone" 
                  dataKey="instagram" 
                  stroke="#E1306C"
                  fill="#E1306C"
                  fillOpacity={0.1}
                />
                <Area 
                  type="monotone" 
                  dataKey="tiktok" 
                  stroke="#69C9D0"
                  fill="#69C9D0"
                  fillOpacity={0.1}
                />
              </AreaChart>
            </ResponsiveContainer>
          </div>
        </div>

        {/* Engagement Times Chart */}
        <div className="bg-white dark:bg-gray-800 rounded-lg p-6 border border-gray-200 dark:border-transparent shadow-sm">
          <div className="flex items-center justify-between mb-6">
            <h2 className="text-xl font-bold text-gray-900 dark:text-white">Meilleurs moments d&apos;engagement</h2>
            <select className="bg-gray-100 dark:bg-gray-700 text-gray-900 dark:text-white text-sm rounded-md px-3 py-2 border-0 focus:ring-2 focus:ring-blue-500">
              <option>Aujourd&apos;hui</option>
              <option>Cette semaine</option>
            </select>
          </div>
          <div className="h-64">
            <ResponsiveContainer width="100%" height="100%">
              <LineChart data={engagementData}>
                <CartesianGrid strokeDasharray="3 3" stroke={colors.gridStroke} />
                <XAxis dataKey="time" stroke={colors.axisStroke} />
                <YAxis stroke={colors.axisStroke} />
                <Tooltip 
                  contentStyle={{ 
                    backgroundColor: colors.tooltipBg,
                    border: colors.tooltipBorder,
                    borderRadius: '0.5rem',
                    color: colors.tooltipText
                  }}
                />
                <Line 
                  type="monotone" 
                  dataKey="instagram" 
                  stroke="#E1306C" 
                  strokeWidth={2}
                  dot={{ fill: '#E1306C' }}
                />
                <Line 
                  type="monotone" 
                  dataKey="tiktok" 
                  stroke="#69C9D0" 
                  strokeWidth={2}
                  dot={{ fill: '#69C9D0' }}
                />
              </LineChart>
            </ResponsiveContainer>
          </div>
        </div>
      </div>


      {/* Trending Hashtags */}
      <div className="bg-white dark:bg-gray-800 rounded-lg p-6 border border-gray-200 dark:border-transparent shadow-sm">
        <div className="flex items-center justify-between mb-6">
          <h2 className="text-xl font-bold text-gray-900 dark:text-white">Hashtags tendance</h2>
          <select className="bg-gray-100 dark:bg-gray-700 text-gray-900 dark:text-white text-sm rounded-md px-3 py-2 border-0 focus:ring-2 focus:ring-blue-500">
            <option>Global</option>
            <option>Votre niche</option>
          </select>
        </div>

        <div className="space-y-4">
          {trendingHashtags.map((item) => (
            <div key={item.tag} className="flex items-center justify-between p-4 hover:bg-gray-50 dark:hover:bg-gray-700/50 rounded-lg transition-colors">
              <div className="flex items-center space-x-4">
                <div className="text-lg font-medium text-blue-500 dark:text-blue-400">
                  {item.tag}
                </div>
              </div>
              <div className="flex items-center space-x-6">
                <div className="text-right">
                  <div className="text-gray-900 dark:text-white font-medium mb-1">{item.posts}</div>
                  <span className="text-sm text-gray-600 dark:text-gray-400">Total des publications</span>
                </div>
                <div className="text-right">
                  <div className="text-green-500 font-medium">{item.growth}</div>
                  <span className="text-sm text-gray-600 dark:text-gray-400">Croissance</span>
                </div>
              </div>
            </div>
          ))}
        </div>
      </div>
    </div>
  )
}