// src/app/not-found.tsx
'use client'

import { useRouter } from 'next/navigation'
import { Home, ArrowLeft, Search } from 'lucide-react'

export default function NotFound() {
  const router = useRouter()
  
  return (
    <div className="min-h-screen bg-white dark:bg-gray-900 flex flex-col items-center justify-center px-6">
      {/* 404 Heading with Gradient */}
      <div className="relative">
        <h1 className="text-[150px] font-bold text-transparent bg-clip-text bg-gradient-to-r from-blue-600 to-purple-600 leading-none select-none">
          404
        </h1>
        <div className="absolute -bottom-2 left-0 right-0 h-2 bg-gradient-to-r from-blue-600/20 to-purple-600/20 blur-sm" />
      </div>

      {/* Error Message */}
      <h2 className="mt-8 text-3xl font-bold text-gray-900 dark:text-white text-center">
        Page not found
      </h2>
      <p className="mt-4 text-gray-600 dark:text-gray-400 text-center max-w-md">
        Sorry, we couldn ot find the page you are looking for. It might have been moved or does not exist.
      </p>

      {/* Action Buttons */}
      <div className="mt-12 flex flex-col sm:flex-row gap-4">
        <button
          onClick={() => router.back()}
          className="inline-flex items-center justify-center px-6 py-3 border border-gray-200 dark:border-gray-700 rounded-lg text-gray-900 dark:text-white hover:bg-gray-50 dark:hover:bg-gray-800 transition-colors duration-200"
        >
          <ArrowLeft className="w-5 h-5 mr-2" />
          Go back
        </button>

        <button
          onClick={() => router.push('/dashboard')}
          className="inline-flex items-center justify-center px-6 py-3 bg-blue-600 rounded-lg text-white hover:bg-blue-700 transition-colors duration-200"
        >
          <Home className="w-5 h-5 mr-2" />
          Back to Dashboard
        </button>
      </div>

      {/* Search Suggestion */}
      <div className="mt-12 w-full max-w-md">
        <div className="relative">
          <Search className="absolute left-3 top-1/2 transform -translate-y-1/2 w-5 h-5 text-gray-400" />
          <input
            type="text"
            placeholder="Search for pages..."
            className="w-full pl-10 pr-4 py-3 bg-gray-50 dark:bg-gray-800 border border-gray-200 dark:border-gray-700 rounded-lg text-gray-900 dark:text-white placeholder-gray-500 dark:placeholder-gray-400 focus:outline-none focus:ring-2 focus:ring-blue-500"
          />
        </div>
      </div>

      {/* Quick Links */}
      <div className="mt-12">
        <h3 className="text-gray-600 dark:text-gray-400 text-sm font-medium mb-4 text-center">
          Quick Links
        </h3>
        <div className="flex flex-wrap justify-center gap-4">
          {['Trends', 'Suggestions', 'Design', 'Ads', 'Showcase'].map((link) => (
            <button
              key={link}
              onClick={() => router.push(`/dashboard/${link.toLowerCase()}`)}
              className="px-4 py-2 text-sm text-gray-700 dark:text-gray-300 hover:text-gray-900 dark:hover:text-white bg-gray-50 dark:bg-gray-800/50 rounded-full transition-colors duration-200 hover:bg-gray-100 dark:hover:bg-gray-700/50"
            >
              {link}
            </button>
          ))}
        </div>
      </div>
    </div>
  )
}