// src/app/page.tsx
'use client'

import {Moon, Sun } from 'lucide-react'
import Image from 'next/image'
import byom from '@/app/assets/byom.png'
import { useTheme } from '@/contexts/themecontext'

export default function HomePage() {

  const { theme, toggleTheme } = useTheme();



  return (
    <div className={`min-h-screen ${theme === 'dark' ? 'bg-gray-900' : 'bg-gray-50'} flex flex-col justify-center relative`}>
      {/* Theme Toggle Button */}
      <button
        onClick={toggleTheme}
        className={`absolute top-4 right-4 p-2 rounded-lg ${
          theme === 'dark' 
            ? 'bg-gray-800 hover:bg-gray-700' 
            : 'bg-white hover:bg-gray-100'
        } transition-colors shadow-lg`}
        aria-label="Toggle theme"
      >
        {theme === 'dark' ? (
          <Sun className="w-5 h-5 text-yellow-500" />
        ) : (
          <Moon className="w-5 h-5 text-gray-600" />
        )}
      </button>
            
      <div className="sm:mx-auto sm:w-full sm:max-w-md px-4">
        {/* Logo */}
        <div className="flex justify-center mb-8">
          <div className="rounded-lg flex items-center justify-center">
            <Image 
              src={byom} 
              alt="BYOM" 
              width={300}
              className={`${theme === 'dark' ? '' : 'invert'} transition-all duration-300`}
            />
          </div>
        </div>
      </div>
    </div>
  )
}