// src/components/InviteCollaborators.tsx
'use client'

import { useState } from 'react';
import { UserPlus, ChevronDown, X } from 'lucide-react';
import { inviteUser } from '@/lib/api/core';
import { useTheme } from '@/contexts/themecontext';

export default function InviteCollaborators({ onClose }: { onClose: () => void }) {
  const [email, setEmail] = useState('');
  const [role, setRole] = useState('Éditeur');
  const [isOpen, setIsOpen] = useState(false);
  const { theme } = useTheme();

  const roles = ['Admin', 'Éditeur', 'Spectateur'];

  const handleInvite = async () => {
    // Send invitation logic (e.g., API call)
    console.log(`Inviting ${email} as ${role}`);

    // retrieve workspaceId from context or local storage
    try {
      //get workspaceId from context or local storage
      const workspaceId = localStorage.getItem('selectedWorkspaceId') || '';
      const data = { email, role, workspace_id: workspaceId };
      await inviteUser(data);
    } catch (err) {
      console.error('Failed to send invitation, error:', err);
    } finally {
      setEmail(''); // Clear input after sending
      onClose();
    }
  };

  return (
    <div className={`${theme === 'dark' ? 'bg-gray-800' : 'bg-white'} rounded-lg p-6 max-w-md w-full shadow-lg relative`}>
      {/* Close Button */}
      <button
        onClick={onClose}
        className={`absolute top-4 right-4 p-2 rounded-lg ${
          theme === 'dark' 
            ? 'hover:bg-gray-700 text-gray-400 hover:text-gray-300' 
            : 'hover:bg-gray-100 text-gray-600 hover:text-gray-700'
        } transition-colors`}
        aria-label="Close"
      >
        <X className="w-5 h-5" />
      </button>

      <h2 className={`text-xl font-bold ${theme === 'dark' ? 'text-white' : 'text-gray-900'} mb-4`}>
        Inviter des Collaborateurs
      </h2>
      
      {/* Email Input */}
      <div className="mb-4">
        <label htmlFor="email" className={`block text-sm font-medium ${theme === 'dark' ? 'text-gray-400' : 'text-gray-600'} mb-1`}>
          Adresse Email
        </label>
        <input
          type="email"
          id="email"
          placeholder="Entrez l'email du collaborateur"
          value={email}
          onChange={(e) => setEmail(e.target.value)}
          className={`w-full ${
            theme === 'dark' 
              ? 'bg-gray-700 text-white placeholder-gray-400' 
              : 'bg-gray-50 text-gray-900 placeholder-gray-500'
          } rounded-lg px-4 py-2 focus:ring-2 focus:ring-blue-500`}
        />
      </div>

      {/* Role Dropdown */}
      <div className="mb-6">
        <label htmlFor="role" className={`block text-sm font-medium ${theme === 'dark' ? 'text-gray-400' : 'text-gray-600'} mb-1`}>
          Rôle
        </label>
        <div className="relative">
          <button
            onClick={() => setIsOpen(!isOpen)}
            className={`w-full ${
              theme === 'dark' 
                ? 'bg-gray-700 text-white' 
                : 'bg-gray-50 text-gray-900'
            } rounded-lg px-4 py-2 flex items-center justify-between`}
          >
            <span>{role}</span>
            <ChevronDown className="w-4 h-4" />
          </button>
          {isOpen && (
            <div className={`absolute mt-2 w-full ${
              theme === 'dark' 
                ? 'bg-gray-700' 
                : 'bg-white'
            } rounded-lg shadow-lg z-10`}>
              {roles.map((r) => (
                <button
                  key={r}
                  onClick={() => {
                    setRole(r);
                    setIsOpen(false);
                  }}
                  className={`w-full px-4 py-2 text-left ${
                    theme === 'dark'
                      ? 'text-white hover:bg-gray-600'
                      : 'text-gray-900 hover:bg-gray-50'
                  }`}
                >
                  {r}
                </button>
              ))}
            </div>
          )}
        </div>
      </div>

      {/* Invite Button */}
      <button
        onClick={handleInvite}
        disabled={!email}
        className="w-full bg-blue-500 text-white px-4 py-2 rounded-lg flex items-center justify-center space-x-2 hover:bg-blue-600 disabled:bg-gray-600 disabled:cursor-not-allowed transition-colors"
      >
        <UserPlus className="w-4 h-4" />
        <span>Envoyer l&apos;Invitation</span>
      </button>
    </div>
  );
}